hash

Macro hash 

hash!() { /* proc-macro */ }
Hashes literal input at compile time and expands to the canonical Crockford Base32 form as a &'static str.

Accepts a string literal, byte string literal, byte array literal, or byte repeat expression. The expansion equals the runtime ps_hash::hash(input)?.to_string() for the same input. Any other input produces a compile error.

Examples

const HASH: &str = ps_hash_macros::hash!("hello");

assert_eq!(HASH.len(), 77);
assert_eq!(HASH, ps_hash_macros::hash!(b"hello"));
assert_eq!(HASH, ps_hash_macros::hash!([b'h', b'e', b'l', b'l', b'o']));