pub fn decoded_len(bytes: &[u8]) -> usizeExpand description
Returns the number of output bytes of decode that bytes fully
determines.
Only the characters the lenient decoder accepts contribute bits (ASCII
whitespace and = are skipped), and a trailing character group that fills
its last byte only partially does not count that byte.